using System;
using FooTheory.CodeCamp.DI.DataAccess;
using FooTheory.CodeCamp.DI.Interfaces.DataAccess;
using FooTheory.CodeCamp.DI.Interfaces.Domain;
using FooTheory.CodeCamp.DI.Interfaces.DTO;
using FooTheory.CodeCamp.DI.Interfaces.Services;
using FooTheory.CodeCamp.DI.Interfaces.Services.Mappers;
using FooTheory.CodeCamp.DI.Services.Mappers;
using Microsoft.Practices.Unity;

namespace FooTheory.CodeCamp.DI.Services
{

    #region DI Implementation

    public class CustomerService : ICustomerService
    {

        #region DI

        private ICustomerRepository repository;
        private ICustomerDTOMapper mapper;

        public CustomerService(
            ICustomerRepository repository,
            ICustomerDTOMapper mapper)
        {
            this.repository = repository;
            this.mapper = mapper;
        }

        #region Lazy Mans DI

        public CustomerService()
            : this(new CustomerRepository(), new CustomerDTOMapper())
        {

        }

        #endregion


        #region ICustomerService Members

        public CustomerDTO GetACustomerFrom(int id)
        {
            return mapper.MapFrom(repository.GetFrom(id));
        }

        #endregion

        #endregion

        private string invalidCustomerName;
        [Dependency]
        public string InvalidCustomerName
        {
            get
            {
                return invalidCustomerName;
            }
            set
            {
                invalidCustomerName = value;
            }
        }


    }

    #endregion

    #region Non DI Implementation

    //public class CustomerService
    //{

    //    private string invalidCustomerName;

    //    public string InvalidCustomerName
    //    {
    //        get
    //        {
    //            return invalidCustomerName;
    //        }
    //        set
    //        {
    //            invalidCustomerName = value;
    //        }
    //    }


    //    public CustomerDTO GetACustomerFrom(int id)
    //    {
    //        CustomerDTOMapper dtoMapper = new CustomerDTOMapper();
    //        CustomerRepository custRepository = new CustomerRepository();

    //        ICustomer customer = custRepository.GetFrom(id);
    //        CustomerDTO dto = dtoMapper.MapFrom(customer);

    //        return dto;
    //    }

    //}

    #endregion

}